@@ -241,6 +241,13 @@ class InvoiceRecipientPartyIdentifier(Element):
     tag = 'InvoiceRecipientPartyIdentifier'
 
 
+class InvoiceRecipientOrganisationTaxCode(Element):
+    """
+    InvoiceRecipientOrganisationName
+    """
+    tag = 'InvoiceRecipientOrganisationTaxCode'
+
+
 class InvoiceRecipientPostCodeIdentifier(Element):
     """
     InvoiceRecipientPostCodeIdentifier
@@ -331,5 +338,5 @@ class InvoiceRecipientPartyDetails(Element):
     tag = 'InvoiceRecipientPartyDetails'
     aggregate = [InvoiceRecipientPartyIdentifier,
         InvoiceRecipientOrganisationName,
-        InvoiceRecipientOrganisationName,
+        InvoiceRecipientOrganisationTaxCode,
             InvoiceRecipientPostalAddressDetails, ]
