@@ -492,34 +492,28 @@ class Row(object):
     def __init__(self, row):
         self.name = row.ArticleNameSet.as_string()
 
-        if len(row.DeliveredQuantitySet) > 0:
-            delivered_quantity = row.DeliveredQuantitySet[0].text
-            try:
-                self.quantity = Decimal(delivered_quantity)
-            except Exception:
-                pass
-            unit_codes = []
-            for q in row.DeliveredQuantitySet:
-                unit_code = ("%s %s"
-                             % (q.text,
-                             q.attributes.get('quantityunitcode', ''))).strip()
-                unit_codes.append(unit_code)
-            self.unit_code = '\n'.join(unit_codes)
+        def get_QuantitySetData(set):
+            if len(set) > 0:
+                quantity = set[0].text
+                try:
+                    self.quantity = Decimal(quantity)
+                except Exception:
+                    pass
+                unit_codes = [set[0].attributes.get('quantityunitcode', '').strip()]
 
-        # TODO: Refactor
-        if self.quantity < 1 and len(row.ConfirmedQuantitySet)>0:
-            confirmed_quantity = row.ConfirmedQuantitySet[0].text
-            try:
-                self.quantity = Decimal(confirmed_quantity)
-            except Exception:
-                pass
-            unit_codes = []
-            for q in row.ConfirmedQuantitySet:
-                unit_code = ("%s %s"
-                             % (q.text,
-                             q.attributes.get('quantityunitcode', ''))).strip()
-                unit_codes.append(unit_code)
-            self.unit_code = '\n'.join(unit_codes)
+                for q in set[1:]:
+                    unit_code = ("%s %s"
+                                 % (q.text,
+                                 q.attributes.get('quantityunitcode', ''))).strip()
+                    unit_codes.append(unit_code)
+                self.unit_code = '\n'.join(unit_codes)
+ 
+        get_QuantitySetData(row.DeliveredQuantitySet)
+
+        if self.quantity < 1:
+            get_QuantitySetData(row.ConfirmedQuantitySet)
+        if self.quantity < 1:
+            get_QuantitySetData(row.OrderedQuantitySet)
 
         unit_price = row.UnitPriceAmountSet
         if len(unit_price) > 0 and unit_price[0]:
@@ -573,7 +567,7 @@ class Row(object):
         for element in row.RowFreeTextSet:
             if not self.freetext:
                 self.freetext = ''
-            self.freetext += '%s\n' % (element.text, )
+            self.freetext += '%s\n' % ((element.text or ''), )
 
     def dict(self):
         return {
